@@ -7,7 +7,8 @@ from aredis_om.connections import get_redis_connection
 @lru_cache(maxsize=None)
 async def check_for_command(conn, cmd):
     cmd_info = await conn.execute_command("command", "info", cmd)
-    return not None in cmd_info
+    return None not in cmd_info
+
 
 @lru_cache(maxsize=None)
 async def has_redis_json(conn=None):
@@ -16,6 +17,7 @@ async def has_redis_json(conn=None):
     command_exists = await check_for_command(conn, "json.set")
     return command_exists
 
+
 @lru_cache(maxsize=None)
 async def has_redisearch(conn=None):
     if conn is None:
