@@ -1114,8 +1114,10 @@ class RedisModel(BaseModel, abc.ABC, metaclass=ModelMeta):
         pk = getattr(self, self._meta.primary_key.field.name)
         return self.make_primary_key(pk)
 
-    def delete(self):
-        return self.db().delete(self.key())
+    @classmethod
+    def delete(cls, pk: Any) -> int:
+        """Delete data at this key."""
+        return cls.db().delete(cls.make_primary_key(pk))
 
     @classmethod
     def get(cls, pk: Any) -> "RedisModel":
